# Autoscaler: replaces squads.
- ask the planner agent to plan work and identify areas that can be worked on in parallel
- ask the planner to determine a recommended number of coder agents
- orc can determine how many qa agents to run based on the number of PRs awaiting merge to dev

# Daemonic orc
- `orc up`: starts the orc process, who sits idle if they don't have work to do
- `orc down`: stops the orc process, killing all agents and cleaning up any resources used by orc
- figure out how to implement `orc status` given it's now a daemon process; perhaps the processes should talk via unix socket
- wake the orc up whenever there's a push to the main branch: the orc can check if there's new vision to process

# Orc Army
- Allow the user to work with orc on multiple feature branches instead of a single 'main' branch.
- right now if I'm working in parallel on feat/foo and feat/bar, if I put my orc config in feat/foo and run orc, it will open a dev branch that mirrors feat/foo and open PRs on top of that. But I don't have a way to have two separate orcs running on foo and on bar.
- Figure out which strategy we want: 
  - a single orc managing work on different branches (the same pool of agents can pick up whatever work is available on either one)
    - harder to optimize context usage: the agents will have to switch contexts between potentially unrelated branches
  - give every branch its own orc
    - better separation, but also more complex to implement
     